package com.leanplum.sample;

import android.content.Intent;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Bundle;
import android.view.Menu;
import android.view.View;
import android.widget.ImageView;
import android.widget.TextView;

import com.leanplum.Leanplum;
import com.leanplum.activities.LeanplumActivity;
import com.leanplum.callbacks.VariablesChangedCallback;

public class MainActivity extends LeanplumActivity {
  /**
   * Callback for when Leanplum is ready with all variables and assets. Also fires any time there is
   * a change.
   */
  private VariablesChangedCallback varsAndFilesChanged = null;

  private ImageView imageView;

  @Override
  protected void onCreate(Bundle savedInstanceState) {
    super.onCreate(savedInstanceState);

    // Sets the contentView after Leanplum is started, so that
    // if one of the views changes and is cached across sessions,
    // it is ready immediately.
    setContentView(R.layout.loading);

    // Listens to when variables and assets change.
    setLeanplumCallback();
  }

  /**
   * Registers the Leanplum callback for when variables and assets change.
   */
  private void setLeanplumCallback() {
    if (varsAndFilesChanged != null) {
      Leanplum.removeVariablesChangedAndNoDownloadsPendingHandler(varsAndFilesChanged);
    }
    varsAndFilesChanged = new VariablesChangedCallback() {
      @Override
      public void variablesChanged() {
        init();
      }
    };
    Leanplum.addVariablesChangedAndNoDownloadsPendingHandler(varsAndFilesChanged);
  }

  /**
   * Initialize the view.
   */
  private void init() {
    // By extending LeanplumActivity, Leanplum will automatically
    // swap out the layout if it's changed on the dashboard.
    // For fragments, you'd use LeanplumInflater instead.
    setContentView(R.layout.activity_main);
    setTitle(MyApp.title);

    TextView textView = (TextView) findViewById(R.id.textView);
    textView.setText(MyApp.mainText);

    imageView = (ImageView) findViewById(R.id.imageView1);
    imageView.setImageBitmap(BitmapFactory.decodeStream(MyApp.promo.stream()));
    imageView.setOnClickListener(new View.OnClickListener() {
      @Override
      public void onClick(View arg0) {
        Leanplum.track("Clicked Promo");
        if (MyApp.promoTouchEnabled) {
          Intent marketIntent = new Intent(Intent.ACTION_VIEW);
          marketIntent.setData(Uri.parse(MyApp.MARKET_URL));
          startActivity(marketIntent);
        }
      }
    });
  }

  @Override
  public boolean onCreateOptionsMenu(Menu menu) {
    // Inflate the menu; this adds items to the action bar if it is present.
    getMenuInflater().inflate(R.menu.activity_main, menu);
    return true;
  }
}
